@@ -117,10 +117,6 @@
  *       gamin's approach sounds good: let the user watch an inode using several
  *       different filenames, and when an event occurs on the inode, generate an
  *       event for each filename.
- *
- * @todo Improve wd/filename storage.  At the moment a doubly-linked list is used,
- *       so lookups take linear time.  This could be a problem if watching
- *       hundreds of thousands of files.
  */
 
 #define MAX_EVENTS 4096
@@ -767,7 +763,9 @@ char * inotifytools_event_to_str_sep(int events, char sep)
 char * inotifytools_filename_from_wd( int wd ) {
 	niceassert( init, "inotifytools_initialize not called yet" );
 	watch *w = watch_from_wd(wd);
-	if (!w) return 0;
+	if (!w)
+        return NULL;
+
 	return w->filename;
 }
 
